@@ -1,6 +1,4 @@
 # vim:fileencoding=utf-8
-# Copyright (c) 2007-2011 gocept gmbh & co. kg
-# See also LICENSE.txt
 """Interaction between the reference machinery and content objects."""
 
 import transaction
@@ -32,17 +30,16 @@ def sublocation_tree(obj):
                 yield sub
 
 
+@zope.component.adapter(zope.interface.Interface)
+@zope.interface.implementer(gocept.reference.interfaces.IReferenceSource)
 class ReferenceSource(object):
 
-    zope.interface.implements(gocept.reference.interfaces.IReferenceSource)
-    zope.component.adapts(zope.interface.Interface)
-
     def __init__(self, context):
         self.context = context
 
     def verify_integrity(self):
         for name, ref in find_references(
-            self.context):
+                self.context):
             target_key = gocept.reference.reference.get_storage(
                 self.context).get(name)
             if target_key:
@@ -53,11 +50,10 @@ class ReferenceSource(object):
         return True
 
 
+@zope.component.adapter(zope.interface.Interface)
+@zope.interface.implementer(gocept.reference.interfaces.IReferenceTarget)
 class ReferenceTarget(object):
 
-    zope.interface.implements(gocept.reference.interfaces.IReferenceTarget)
-    zope.component.adapts(zope.interface.Interface)
-
     def __init__(self, context):
         self.context = context
 
