@@ -6,12 +6,13 @@
 import transaction
 from persistent.dict import PersistentDict
 
-import zope.site.hooks
+import zope.component.hooks
 import zope.annotation.interfaces
 import zope.traversing.interfaces
 import zope.traversing.api
 
 import gocept.reference.interfaces
+import six
 
 
 def find_name(method):
@@ -31,11 +32,11 @@ def find_name(method):
         # We cannot simply iterate over dir(cls) since trying to get the
         # attributes would then lead to infinite recursion.
         for cls_ in cls.mro():
-            for name, attr in cls_.__dict__.iteritems():
+            for name, attr in six.iteritems(cls_.__dict__):
                 if attr is descriptor:
                     return name
         else:
-            raise RuntimeError(
+            raise RuntimeError(  # pragma: no cover
                 "Can not automatically find name for reference. "
                 "This place in the code should never be reached.")
 
@@ -54,7 +55,7 @@ def get_manager():
 
 
 def get_root():
-    site = zope.site.hooks.getSite()
+    site = zope.component.hooks.getSite()
     locatable = zope.traversing.interfaces.IPhysicallyLocatable(site)
     return locatable.getRoot()
 
