@@ -1,7 +1,4 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2007-2010 gocept gmbh & co. kg
-# See also LICENSE.txt
-
 import doctest
 import os.path
 import zope.annotation.interfaces
@@ -15,6 +12,7 @@ import gocept.reference
 ftesting_zcml = os.path.join(os.path.dirname(__file__), 'ftesting.zcml')
 FunctionalLayer = zope.app.testing.functional.ZCMLLayer(
     ftesting_zcml, __name__, 'FunctionalLayer')
+FunctionalLayer.allow_teardown = True
 
 
 def FunctionalDocFileSuite(*paths, **kw):
@@ -26,36 +24,32 @@ def FunctionalDocFileSuite(*paths, **kw):
     return suite
 
 
-class Address(zope.container.contained.Contained):
-
-    zope.interface.implements(
+@zope.interface.implementer(
         zope.annotation.interfaces.IAttributeAnnotatable)
+class Address(zope.container.contained.Contained):
 
     city = gocept.reference.Reference()
 
 
-class City(zope.container.contained.Contained):
-
-    zope.interface.implements(
+@zope.interface.implementer(
         zope.annotation.interfaces.IAttributeAnnotatable)
+class City(zope.container.contained.Contained):
 
     cultural_institutions = gocept.reference.ReferenceCollection(
         ensure_integrity=True)
 
 
-class Village(zope.container.contained.Contained):
-
-    zope.interface.implements(
+@zope.interface.implementer(
         zope.annotation.interfaces.IAttributeAnnotatable)
+class Village(zope.container.contained.Contained):
 
     cultural_institutions = gocept.reference.ReferenceCollection(
         ensure_integrity=False)
 
 
-class Monument(zope.container.contained.Contained):
-
-    zope.interface.implements(
+@zope.interface.implementer(
         zope.annotation.interfaces.IAttributeAnnotatable)
+class Monument(zope.container.contained.Contained):
 
     city = gocept.reference.Reference(ensure_integrity=True)
 
