@@ -1,15 +1,12 @@
-# -*- coding: latin-1 -*-
-# Copyright (c) 2007-2010 gocept gmbh & co. kg
-# See also LICENSE.txt
-"""Tests for gocept.reference"""
-
-import unittest
-import zope.interface.verify
-
+import doctest
 import gocept.reference.content
 import gocept.reference.interfaces
 import gocept.reference.manager
 import gocept.reference.testing
+import re
+import six
+import unittest
+import zope.interface.verify
 
 
 class TestInterfaces(unittest.TestCase):
@@ -36,24 +33,35 @@ class TestContentFunctions(unittest.TestCase):
         class BrokenDescriptor(object):
             def __get__(self, instance, *args, **kw):
                 raise AttributeError()
+
         class BrokenAttribute(object):
             asdf = BrokenDescriptor()
         obj = BrokenAttribute()
-        self.assertEquals(
+        self.assertEqual(
             [],
             list(gocept.reference.content.find_references(obj)))
 
 
+class Py23DocChecker(doctest.OutputChecker):
+    def check_output(self, want, got, optionflags):
+        if six.PY3:
+            want = re.sub("u'(.*?)'", "'\\1'", want)
+            want = re.sub('u"(.*?)"', '"\\1"', want)
+        return doctest.OutputChecker.check_output(self, want, got, optionflags)
+
+
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTest(unittest.makeSuite(TestInterfaces))
     suite.addTest(unittest.makeSuite(TestContentFunctions))
     suite.addTest(gocept.reference.testing.FunctionalDocFileSuite(
-            'reference.txt',
-            'collection.txt',
-            'verify.txt',
-            'regression.txt',
-            'field.txt',
-            'fix.txt',
-            ))
+        'reference.txt',
+        'collection.txt',
+        'verify.txt',
+        'regression.txt',
+        'field.txt',
+        'fix.txt',
+        optionflags=(doctest.IGNORE_EXCEPTION_DETAIL),
+        checker=Py23DocChecker(),
+    ))
     return suite
